==> plugin_codelab_new-0.0.18.tar.gz: lib/plugin_codelab_new.dart <==
import 'package:plugin_codelab_new/models/media.dart';
import 'package:plugin_codelab_new/pages/home_page.dart';
import 'package:plugin_codelab_new/repo/feed_repository.dart';
import 'package:plugin_codelab_new/service/http_service.dart';
import 'package:flutter/material.dart';

import 'bloc/feed_cubit.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:provider/provider.dart';

class FeedPlugin extends StatelessWidget {
  const FeedPlugin(
      {Key key,
      @required this.token,
      @required this.firstName,
      @required this.lastName,
      @required this.about,
      @required this.profileImg,
      @required this.partnerFullName,
      @required this.logo,
      @required this.media})
      : super(key: key);

  final String token;
  final String firstName;
  final String lastName;
  final String about;
  final String profileImg;
  final String partnerFullName;
  final String logo;
  final Media media;

  @override
  Widget build(BuildContext context) {
    return init();
  }

  Widget init() {
    final httpService = HttpService("gogog");
    final feedRepository = FeedRepository(httpService);
    final feedCubit = FeedCubit(feedRepository: feedRepository);
    runApp(
      MultiRepositoryProvider(
        providers: [
          RepositoryProvider<FeedRepository>(
            create: (context) => FeedRepository(httpService),
          )
        ],
        child: MultiBlocProvider(providers: [
          BlocProvider<FeedCubit>(
            create: (context) {
              return feedCubit;
            },
          ),
        ], child: app()),
      ),
    );
    return Text("", textDirection: TextDirection.ltr);
  }

  Widget app() {
    return MaterialApp(
      home: HomePage(
        token: this.token,
        firstName: this.firstName,
        lastName: this.lastName,
        about: this.about,
        profileImg: this.profileImg,
      ),
      routes: <String, WidgetBuilder>{
        '/homePage': (BuildContext context) => new HomePage(
              token: this.token,
              firstName: this.firstName,
              lastName: this.lastName,
              about: this.about,
              profileImg: this.profileImg,
            ),
      },
    );
  }
}

==> plugin_codelab_new-0.0.21.tar.gz: lib/plugin_codelab_new.dart <==
import 'package:plugin_codelab_new/models/media.dart';
import 'package:plugin_codelab_new/pages/home_page.dart';
import 'package:plugin_codelab_new/repo/feed_repository.dart';
import 'package:plugin_codelab_new/service/http_service.dart';
import 'package:flutter/material.dart';

import 'bloc/feed_cubit.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:provider/provider.dart';

class FeedPlugin extends StatelessWidget {
  const FeedPlugin(
      {Key key,
      @required this.token,
      @required this.firstName,
      @required this.lastName,
      @required this.about,
      @required this.profileImg,
      @required this.partnerToken,
      @required this.partnerCompanyName,
      @required this.logo,
      @required this.media})
      : super(key: key);

  final String token;
  final String firstName;
  final String lastName;
  final String about;
  final String profileImg;
  final String partnerToken;
  final String partnerCompanyName;
  final String logo;
  final media;

  @override
  Widget build(BuildContext context) {
    return init();
  }

  Widget init() {
    final httpService = HttpService("gogog");
    final feedRepository = FeedRepository(httpService);
    final feedCubit = FeedCubit(feedRepository: feedRepository);
    runApp(
      MultiRepositoryProvider(
        providers: [
          RepositoryProvider<FeedRepository>(
            create: (context) => FeedRepository(httpService),
          )
        ],
        child: MultiBlocProvider(providers: [
          BlocProvider<FeedCubit>(
            create: (context) {
              return feedCubit;
            },
          ),
        ], child: app()),
      ),
    );
    return Text("", textDirection: TextDirection.ltr);
  }

  Widget app() {
    return MaterialApp(
      home: HomePage(
        token: this.token,
        firstName: this.firstName,
        lastName: this.lastName,
        about: this.about,
        profileImg: this.profileImg,
      ),
      routes: <String, WidgetBuilder>{
        '/homePage': (BuildContext context) => new HomePage(
              token: this.token,
              firstName: this.firstName,
              lastName: this.lastName,
              about: this.about,
              profileImg: this.profileImg,
            ),
      },
    );
  }
}
